Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(191)

Unified Diff: chrome/browser/policy/proto/device_management_backend.proto

Issue 9814011: Rename enterprise policy proto fields from KIOSK to RETAIL. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fixed compilation and addressed comments. Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/policy/proto/chrome_device_policy.proto ('k') | net/tools/testserver/device_management.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/policy/proto/device_management_backend.proto
diff --git a/chrome/browser/policy/proto/device_management_backend.proto b/chrome/browser/policy/proto/device_management_backend.proto
index 9db8cc93e3fbd0668ad30b3750113d926d4487bf..b6396020cf0aa21fab52f869a56a905be6d4ae2a 100644
--- a/chrome/browser/policy/proto/device_management_backend.proto
+++ b/chrome/browser/policy/proto/device_management_backend.proto
@@ -38,11 +38,11 @@ message DeviceRegisterRequest {
// "Android", or "Chrome OS".
optional string machine_model = 4;
- // When true, indicates that the |machine_id| field should be known to the
- // server. The server can do additional checks based on this information.
- // This is currently used for requests triggered by auto-enrollment.
+ // When true, indicates that the |machine_id| has been identified as auto-
+ // enrollment candidate on the client and the server can use it to verify
+ // that the client is to be enrolled in the correct mode.
// Defaults to false when not present.
- optional bool known_machine_id = 5;
+ optional bool auto_enrolled = 5;
}
// Response from server to device register request.
@@ -64,10 +64,10 @@ message DeviceRegisterResponse {
// controlled through the cloud policy infrastructure. Auto-enrollment is
// supported in that mode.
ENTERPRISE = 0;
// Devices in KIOSK mode also have no local owner and get their device
// settings from the cloud, but additionally this mode enables the demo
// account on the device.
- KIOSK = 1;
+ RETAIL = 1;
}
optional DeviceMode enrollment_type = 3 [default = ENTERPRISE];
}
@@ -64,10 +64,10 @@ message DeviceRegisterResponse {
// supported in that mode.
ENTERPRISE = 0;
- // Devices in KIOSK mode also have no local owner and get their device
+ // Devices in RETAIL mode also have no local owner and get their device
// settings from the cloud, but additionally this mode enables the demo
// account on the device.
« no previous file with comments | « chrome/browser/policy/proto/chrome_device_policy.proto ('k') | net/tools/testserver/device_management.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698